django-simpleimages
===================

.. image:: https://pypip.in/v/django-simpleimages/badge.png
        :target: https://crate.io/packages/django-simpleimages

.. image:: https://travis-ci.org/saulshanabrook/django-simpleimages.png
    :target: https://travis-ci.org/saulshanabrook/django-simpleimages

.. image:: https://coveralls.io/repos/saulshanabrook/django-simpleimages/badge.png?branch=master
    :target: https://coveralls.io/r/saulshanabrook/django-simpleimages


``django-simpleimages`` is an opinionated Django app which allows you
to transform images on model saves.

http://django-simpleimages.readthedocs.org/
